searchNodes=[{"ref":"Confy.html","title":"Confy","type":"module","doc":"Confy allows you to make your configuration explicit: Specify exactly what fields are expected. Specify exactly what values these fields might take, by giving them parser-functions. Load their values from a slew of different locations, with &#39;explicitly passed in to the function&#39; as final option."},{"ref":"Confy.html#defconfig/2","title":"Confy.defconfig/2","type":"macro","doc":"Defines a configuration structure in the current module. Fields are added to this configuration structure by calling Confy.Schema.field/3 (which can be called just as field because Confy.Schema is autoamatically imported into the inner context of the call to defconfig.) The options that can be passed to this module are used as defaults for the options passed to a call to Confy.load/2 or YourModule.load/1. See also Confy.Schema.field/3 and Confy.Options Reflection The special function __confy__/1 will be defined on the module as well. It is not intended to be used by people that want to consume your configuration, but it is there to e.g. allow Confy.Provider implementations to be smarter in how they fetch the configuration for the module. For instance, configuration might be lazily fetched, when knowing what field names exist beforehand. YourModule.__confy__/1 supports the following publicly usable parameters: __confy__(:field_names) returns a MapSet of atoms, one per field in the configuration structure. __confy__(:defaults) returns a Map containing only the field_name =&gt; values of field names having default values. __confy__(:requireds) returns a MapSet of atoms, one per required field in the configuration structure. __confy__(:parsers) returns a Map of the format field_name =&gt; parser."},{"ref":"Confy.html#load/2","title":"Confy.load/2","type":"function","doc":"Loads, parses, and normalizes the configuration of config_module, based on the current source settings, returning the result as a struct. (This is the more general way of calling config_module.load/1). See Confy.Options for more information of the options that can be supplied to this function, and how it can be configured further."},{"ref":"Confy.MissingRequiredFieldsError.html","title":"Confy.MissingRequiredFieldsError","type":"exception","doc":"Default exception to be raised when a required field is not existent in any configuration source."},{"ref":"Confy.Options.html","title":"Confy.Options","type":"module","doc":"This struct represents the options you can pass to a call of Confy.load/2 (or YourModule.load/1). Metaconfiguration Besides making it nice and explicit to have the options listed here, Confy.Options has itself been defined using Confy.defconfig/2, which means that it (and thus what default options are passed on to to other Confy configurations) can be configured in the same way. Configuration structure documentation: This configuration was made using the Confy library. It contains the following fields: sources A list of structures that implement the Confy.Provider protocol, which will be used to fetch configuration from. Later entries in the list take precedence over earlier entries. Defaults always have the lowest precedence, and :overrides always have the highest precedence. Validated/parsed by calling &amp;Confy.Options.list_of_sources/1. Defaults to []. overrides A list or map (or other enumerable) representing explicit overrides that are to be used instead of what can be found in the implicit sources stack. Validated/parsed by calling &amp;Confy.Parsers.term/1. Defaults to []. missing_fields_error The error to be raised if a missing field which is required has been encountered. Validated/parsed by calling &amp;Confy.Parsers.term/1. Defaults to Confy.MissingRequiredFieldsError. parsing_error The error to be raised if a field value could not properly be parsed. Validated/parsed by calling &amp;Confy.Parsers.term/1. Defaults to Confy.ParsingError. explain When set to true, rather than returning the config struct, a map is returned with every field-key containing a list of consecutive found values. This is useful for debugging. Validated/parsed by calling &amp;Confy.Parsers.boolean/1. Defaults to false. Metaconfiguration Gotcha&#39;s Confy will only be able to find a source after it knows it exists. This means that it is impossible to define a different set of sources inside an external source. For this special case, Confy will look at the current process&#39; Process dictionary, falling back to the Application environment (also known as the Mix environment), and finally falling back to an empty list of sources (its default). So, from lowest to highest precedence, option values are loaded in this order: Confy.Options default Application Environment :confy Process Dictionary :confy field Options passed to Comfy.defconfig Options passed to YourModule.load Requiring Confy to be configured in such a general way seems highly unlikely. If the current approach does turn out to not be good enough for your use-case, please open an issue on Confy&#39;s issue tracker."},{"ref":"Confy.Options.html#list_of_sources/1","title":"Confy.Options.list_of_sources/1","type":"function","doc":""},{"ref":"Confy.Options.html#load/1","title":"Confy.Options.load/1","type":"function","doc":"Loads, parses, and normalizes the configuration of Confy.Options, based on the current source settings, returning the result as a struct. For more information about the options this function supports, see Confy.load/2 and Confy.Options"},{"ref":"Confy.Parsers.html","title":"Confy.Parsers","type":"module","doc":"Simple functions to parse strings to datatypes commonly used during configuration. These functions can be used as parser/validator function in a call to Confy.Schema.field, by using their shorthand name (:integer as shorthand for &amp;Confy.Parsers.integer/1). (Of course, using their longhand name works as well.) Defining your own parser function A parser function receives the to-be-parsed/validated value as input, and should return {:ok, parsed_val} on success, or {:error, reason} on failure. Be aware that depending on where the configuration is loaded from, the to-be-parsed value might be a binary string, or already the Elixir type you want to convert it to."},{"ref":"Confy.Parsers.html#atom/1","title":"Confy.Parsers.atom/1","type":"function","doc":""},{"ref":"Confy.Parsers.html#boolean/1","title":"Confy.Parsers.boolean/1","type":"function","doc":""},{"ref":"Confy.Parsers.html#float/1","title":"Confy.Parsers.float/1","type":"function","doc":""},{"ref":"Confy.Parsers.html#integer/1","title":"Confy.Parsers.integer/1","type":"function","doc":""},{"ref":"Confy.Parsers.html#string/1","title":"Confy.Parsers.string/1","type":"function","doc":""},{"ref":"Confy.Parsers.html#term/1","title":"Confy.Parsers.term/1","type":"function","doc":""},{"ref":"Confy.Parsers.html#unsafe_atom/1","title":"Confy.Parsers.unsafe_atom/1","type":"function","doc":""},{"ref":"Confy.ParsingError.html","title":"Confy.ParsingError","type":"exception","doc":"Default exception to be raised when it is impossible to parse one of the configuration values. (See also Confy.Parsers)"},{"ref":"Confy.Provider.html","title":"Confy.Provider","type":"protocol","doc":"Protocol to load configuration from a signle source. Configuration Providers implement this protocol, which consists of only one function: load/2."},{"ref":"Confy.Provider.html#load/2","title":"Confy.Provider.load/2","type":"function","doc":"Loads the configuration of specification module from the source indicated by struct. Its first argument is the implementation&#39;s own struct, the second argument being the configuration specification&#39;s module name. If extra information is required about the configuration specification to write a good implementation, the Reflection function module_name.__confy__ can be used to look these up. See also Confy.defconfig/2 and Confy.Options."},{"ref":"Confy.Provider.html#t:t/0","title":"Confy.Provider.t/0","type":"type","doc":""},{"ref":"Confy.Provider.MixEnv.html","title":"Confy.Provider.MixEnv","type":"module","doc":"A Configuration Provider source based on Mix.env() / Application.get_env."},{"ref":"Confy.Provider.MixEnv.html#new/2","title":"Confy.Provider.MixEnv.new/2","type":"function","doc":"By default, will try to use Application.get_all_env(YourConfigModule) to fetch the source&#39;s configuration. A differnt application name can be used by supplying a different application argument. If the actual configuration is only inside one of the keys in this application, the second field key can also be provided."},{"ref":"Confy.Provider.Process.html","title":"Confy.Provider.Process","type":"module","doc":"A Configuration Provider source based on the current process&#39; Process Dictionary."},{"ref":"Confy.Provider.Process.html#new/1","title":"Confy.Provider.Process.new/1","type":"function","doc":"By default, will try to use Process.get(YourModule) to fetch the source&#39;s configuration. A different key can be used by supplying a different key argument."},{"ref":"Confy.Schema.html","title":"Confy.Schema","type":"module","doc":"Functions that can be used inside Confy.defconfig/2."},{"ref":"Confy.Schema.html#field/3","title":"Confy.Schema.field/3","type":"macro","doc":"Specifies a field that is part of the configuration struct. Can/should only be called inside a call to Confy.defconfig. name should be an atom representing the field. It will also become the field name for the struct that is created. parser should either be: an arity-one function reference like &amp;YourModule.some_type_parser/1. An atom representing one of the common parser function names in Confy.Parsers like :integer, :string, :boolean or :term. Supported field options are: default:, supplies a default value to this field. If not set, the configuration field is set to be required. You are highly encouraged to add a @documentation text above each and every field; these will be added to the configuration&#39;s module documentation."}]